@@ -223,8 +223,11 @@ class HiveRepo:
         df = self.read(self.temp_table_name)
         return df
 
-    def delta_stream_upserter(self, stream, partition_cols: tuple = tuple()):
-        return DeltaStreamUpserter(self, partition_cols).execute(stream)
+    def delta_stream_upserter(self,
+                              stream: dataframe.DataFrame,
+                              partition_pruning_col: str = None,
+                              partition_cols: tuple = tuple()):
+        return DeltaStreamUpserter(self, partition_pruning_col, partition_cols).execute(stream)
 
     def write_stream_to_table(self,
                               stream,
@@ -394,8 +397,9 @@ class DeltaStreamUpserter:
     class TemporaryStreamDumpRepo(HiveRepo):
         table_name = "__temp__"
 
-    def __init__(self, repo: HiveRepo, partition_cols: tuple = tuple()):
+    def __init__(self, repo: HiveRepo, partition_pruning_col: str = None, partition_cols: tuple = tuple()):
         self.repo = repo
+        self.partition_pruning_col = partition_pruning_col
         self.partition_cols = partition_cols
         self.temp_id = str(uuid.uuid4()).replace("-", "")
         self.temp_repo = self.TemporaryStreamDumpRepo(db=self.repo.db,
@@ -431,7 +435,7 @@ class DeltaStreamUpserter:
         return monad.Right(self.temp_repo.read(self.temp_table_name(self.temp_repo.table_name)))
 
     def upsert(self, df: DataFrame) -> monad.EitherMonad[DataFrame]:
-        self.repo.upsert(df, self.partition_cols[0], self.partition_cols)
+        self.repo.upsert(df, self.partition_pruning_col, self.partition_cols)
         return monad.Right(df)
 
     def temp_table_name(self, temp_prefix):
